@@ -46,6 +46,15 @@ where
     key2: u128,
 }
 
+unsafe impl<K: Clone + Hash + Eq + Debug + Send + 'static, V: Clone + Send + 'static> Send
+    for SuperBlock<K, V>
+{
+}
+unsafe impl<K: Clone + Hash + Eq + Debug + Sync + Send + 'static, V: Clone + Sync + Send + 'static>
+    Sync for SuperBlock<K, V>
+{
+}
+
 impl<K: Hash + Eq + Clone + Debug, V: Clone> LinCowCellCapable<CursorRead<K, V>, CursorWrite<K, V>>
     for SuperBlock<K, V>
 {
@@ -78,7 +87,7 @@ impl<K: Hash + Eq + Clone + Debug, V: Clone> LinCowCellCapable<CursorRead<K, V>,
         self.txid = new.txid;
 
         // Create the new reader.
-        CursorRead::new(&self)
+        CursorRead::new(self)
     }
 }
 
@@ -141,6 +150,15 @@ where
     last_seen: Mutex<Vec<*mut Node<K, V>>>,
 }
 
+unsafe impl<K: Clone + Hash + Eq + Debug + Send + 'static, V: Clone + Send + 'static> Send
+    for CursorRead<K, V>
+{
+}
+unsafe impl<K: Clone + Hash + Eq + Debug + Sync + Send + 'static, V: Clone + Sync + Send + 'static>
+    Sync for CursorRead<K, V>
+{
+}
+
 #[derive(Debug)]
 pub(crate) struct CursorWrite<K, V>
 where
@@ -157,6 +175,15 @@ where
     first_seen: Vec<*mut Node<K, V>>,
 }
 
+unsafe impl<K: Clone + Hash + Eq + Debug + Send + 'static, V: Clone + Send + 'static> Send
+    for CursorWrite<K, V>
+{
+}
+unsafe impl<K: Clone + Hash + Eq + Debug + Sync + Send + 'static, V: Clone + Sync + Send + 'static>
+    Sync for CursorWrite<K, V>
+{
+}
+
 pub(crate) trait CursorReadOps<K: Clone + Hash + Eq + Debug, V: Clone> {
     fn get_root_ref(&self) -> &Node<K, V>;
 
@@ -426,6 +453,7 @@ impl<K: Clone + Hash + Eq + Debug, V: Clone> CursorWrite<K, V> {
         path_get_mut_ref(self.root, h, k)
     }
 
+    /*
     pub(crate) unsafe fn get_slot_mut_ref(&mut self, h: u64) -> Option<&mut [Datum<K, V>]> {
         match path_clone(
             self.root,
@@ -443,6 +471,7 @@ impl<K: Clone + Hash + Eq + Debug, V: Clone> CursorWrite<K, V> {
         // Now get the ref.
         path_get_slot_mut_ref(self.root, h)
     }
+    */
 
     #[cfg(test)]
     pub(crate) fn root_txid(&self) -> u64 {
@@ -1040,6 +1069,7 @@ where
     }
 }
 
+/*
 unsafe fn path_get_slot_mut_ref<'a, K: Clone + Hash + Eq + Debug, V: Clone>(
     node: *mut Node<K, V>,
     h: u64,
@@ -1064,6 +1094,7 @@ where
         r.map(|v| &mut *v as &mut [Datum<K, V>])
     }
 }
+*/
 
 #[cfg(test)]
 mod tests {
